import { Editor } from 'codemirror';
import type { EditorConfiguration } from 'codemirror';
import { FormatOptions } from 'sql-formatter';
import { default as React_2 } from 'react';

export declare type IEditor = Editor & {
    format(options: Partial<FormatOptions>): void;
};

export declare type IFormatOptions = FormatOptions;

export declare const ReactCodemirror: React_2.ForwardRefExoticComponent<ReactCodemirrorProps & React_2.RefAttributes<Editor>>;

declare type ReactCodemirrorProps = {
    /**
     * @description 编辑器展示的内容文本，改编辑器不太适合作为受控组件出现，最好不要用这个东西来文本的内容，可以通过ref返回的实例的getValue()方法来获取文本的实例。
     * @deprecated
     */
    value?: string;
    /**
     * @description 默认展示的文本内容
     */
    defaultValue?: string;
    /**
     * @description codemirror的配置，
     * @link {https://codemirror.net/doc/manual.html#config}
     */
    options?: EditorConfiguration & {
        formatOptions?: IFormatOptions;
    };
    /**
     * @description editor发生后出发的事件，用来获取更改后，editor的内容
     *
     * @bug 避免在onChange事件中调用修改value的方法，可能会有调用栈移除的风险
     */
    onChange?: (value: string) => void;
    /**
     * @description 拓展自动补全功能，提供外部方法来补从不全的待选项
     */
    extraCompletions?: string[] | ((word: string) => string[] | Promise<string[]>);
    /**
     * 设置编辑器的样式
     */
    theme?: "dark" | "light";
};

export { }
